@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: David Zeuthen <davidz@redhat.com>
  */
@@ -26,8 +24,6 @@
 
 #include "gdbus-tests.h"
 
-static const gchar *binpath;
-
 /* all tests rely on a global connection */
 static GDBusConnection *c = NULL;
 
@@ -116,11 +112,6 @@ main (int   argc,
   gint ret;
   gchar *path;
 
-  if (g_getenv ("G_TEST_DATA"))
-    binpath = g_getenv ("G_TEST_DATA");
-  else
-    binpath = BUILDDIR;
-
   g_test_init (&argc, &argv, NULL);
 
   /* all the tests rely on a shared main loop */
@@ -129,12 +120,11 @@ main (int   argc,
   session_bus_up ();
 
   /* this is safe; testserver will exit once the bus goes away */
-  path = g_build_filename (binpath, "gdbus-testserver", NULL);
+  path = g_test_build_filename (G_TEST_BUILT, "gdbus-testserver", NULL);
   g_assert (g_spawn_command_line_async (path, NULL));
   g_free (path);
 
-  /* wait for the service to come up */
-  usleep (500 * 1000);
+  ensure_gdbus_testserver_up ();
 
   /* Create the connection in the main thread */
   error = NULL;
@@ -146,7 +136,10 @@ main (int   argc,
 
   ret = g_test_run();
 
+  session_bus_down ();
+
   g_object_unref (c);
+  g_main_loop_unref (loop);
 
   return ret;
 }
