@@ -6,7 +6,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -301,7 +301,7 @@ g_unix_fd_source_dispatch (GSource     *source,
 
   if (!callback)
     {
-      g_warning ("GUnixFDSource dispatched without callback\n"
+      g_warning ("GUnixFDSource dispatched without callback. "
                  "You must call g_source_set_callback().");
       return FALSE;
     }
@@ -392,7 +392,7 @@ g_unix_fd_add_full (gint              priority,
  * g_unix_fd_add:
  * @fd: a file descriptor
  * @condition: IO conditions to watch for on @fd
- * @function: a #GPollFDFunc
+ * @function: a #GUnixFDSourceFunc
  * @user_data: data to pass to @function
  *
  * Sets a function to be called when the IO condition, as specified by
